class Configuration:
    'This class represents a single configuration, build from traveloptions, for a request'

    @staticmethod
    def build(travelOptions):

        polygonJson = {
          "values": travelOptions.getTravelTimes(),
          "intersectionMode": travelOptions.getPolygonIntersectionMode().value,
          "serializer": travelOptions.getPolygonSerializationType().value,
          "pointReduction": True,
          "minPolygonHoleSize": travelOptions.getMinPolygonHoleSize()
        }

        if not travelOptions.getBuffer() is None:
            polygonJson['buffer'] = travelOptions.getBuffer();
        if not travelOptions.getSimplifyMeter() is None:
            polygonJson['simplify'] = travelOptions.getSimplifyMeter();
        if not travelOptions.getSrid() is None:
            polygonJson['srid'] = travelOptions.getSrid();
        if not travelOptions.getQuadrantSegments() is None:
            polygonJson['quadrantSegments'] = travelOptions.getQuadrantSegments();

        return {
            "sources": travelOptions.getSources(),
            "polygon" : polygonJson
        };



import json
import requests
import urllib.parse
from r360_py.util.Configuration import Configuration

class PolygonService:
    'This class should be used to query the polygon service'

    def __init__(self):
        return

    def getPolygons(self, travelOptions):

        params = {
            "key" : travelOptions.getServiceKey(),
            "cfg" : json.dumps(Configuration.build(travelOptions))
        }

        r = requests.get(travelOptions.getServiceUrl() + 'v1/polygon', params=params)

        if ( r.status_code == 403 ):
            raise PermissionError(r.text)

        return json.loads(r.text)
